==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/HoleDimensionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HoleDimensionsChangedEventArgsDescription } from "./HoleDimensionsChangedEventArgsDescription";
/**
 * @hidden
 */
var HoleDimensionsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(HoleDimensionsChangedEventArgsDescriptionMetadata, _super);
    function HoleDimensionsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HoleDimensionsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (HoleDimensionsChangedEventArgsDescriptionMetadata.a == null) {
            HoleDimensionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HoleDimensionsChangedEventArgsDescriptionMetadata.c(HoleDimensionsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(HoleDimensionsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(HoleDimensionsChangedEventArgsDescriptionMetadata.a);
    };
    HoleDimensionsChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    HoleDimensionsChangedEventArgsDescriptionMetadata.d = function (a) {
        HoleDimensionsChangedEventArgsDescriptionMetadata.b(a);
        a.u("HoleDimensionsChangedEventArgs", function () { return new HoleDimensionsChangedEventArgsDescription(); });
        a.t("HoleDimensionsChangedEventArgs", HoleDimensionsChangedEventArgsDescriptionMetadata.a);
    };
    HoleDimensionsChangedEventArgsDescriptionMetadata.$t = markType(HoleDimensionsChangedEventArgsDescriptionMetadata, 'HoleDimensionsChangedEventArgsDescriptionMetadata');
    HoleDimensionsChangedEventArgsDescriptionMetadata.a = null;
    return HoleDimensionsChangedEventArgsDescriptionMetadata;
}(Base));
export { HoleDimensionsChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/HoleDimensionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HoleDimensionsChangedEventArgsDescription } from "./HoleDimensionsChangedEventArgsDescription";
/**
 * @hidden
 */
var HoleDimensionsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(HoleDimensionsChangedEventArgsDescriptionMetadata, _super);
    function HoleDimensionsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HoleDimensionsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (HoleDimensionsChangedEventArgsDescriptionMetadata.a == null) {
            HoleDimensionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HoleDimensionsChangedEventArgsDescriptionMetadata.c(HoleDimensionsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(HoleDimensionsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(HoleDimensionsChangedEventArgsDescriptionMetadata.a);
    };
    HoleDimensionsChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    HoleDimensionsChangedEventArgsDescriptionMetadata.d = function (a) {
        HoleDimensionsChangedEventArgsDescriptionMetadata.b(a);
        a.aa("HoleDimensionsChangedEventArgs", function () { return new HoleDimensionsChangedEventArgsDescription(); });
        a.z("HoleDimensionsChangedEventArgs", HoleDimensionsChangedEventArgsDescriptionMetadata.a);
    };
    HoleDimensionsChangedEventArgsDescriptionMetadata.$t = markType(HoleDimensionsChangedEventArgsDescriptionMetadata, 'HoleDimensionsChangedEventArgsDescriptionMetadata');
    HoleDimensionsChangedEventArgsDescriptionMetadata.a = null;
    return HoleDimensionsChangedEventArgsDescriptionMetadata;
}(Base));
export { HoleDimensionsChangedEventArgsDescriptionMetadata };
